pub struct Clk1MConfig;Expand description
A basic type that always returns Ok when PreEnableParts is called.
This should only be used for peripherals that are clocked only by the CLK1M clock and have no other selectable/configurable source clock.